==> jc-1.4.0.tar.gz: java/awt/font/GraphicAttribute.h <==
// public abstract class java.awt.font.GraphicAttribute

// class file dependencies
// @dep_class a87844304b3211dc java_awt_font_GraphicAttribute
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_font_GraphicAttribute_H_
#define _JC_java_awt_font_GraphicAttribute_H_

// Forward structure declarations
struct _jc_java_awt_Graphics2D$object;
struct _jc_java_awt_font_GlyphJustificationInfo$object;
struct _jc_java_awt_geom_Rectangle2D$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_font_GraphicAttribute$sub_refs	_jc_java_awt_font_GraphicAttribute$sub_refs;
typedef struct _jc_java_awt_font_GraphicAttribute$sub_nonrefs	_jc_java_awt_font_GraphicAttribute$sub_nonrefs;
typedef struct _jc_java_awt_font_GraphicAttribute$refs	_jc_java_awt_font_GraphicAttribute$refs;
typedef struct _jc_java_awt_font_GraphicAttribute$nonrefs	_jc_java_awt_font_GraphicAttribute$nonrefs;
typedef struct _jc_java_awt_font_GraphicAttribute$object	_jc_java_awt_font_GraphicAttribute$object;

typedef struct _jc_java_awt_font_GraphicAttribute$fields_struct	_jc_java_awt_font_GraphicAttribute$fields_struct;
typedef const struct _jc_java_awt_font_GraphicAttribute$vmethods	_jc_java_awt_font_GraphicAttribute$vmethods;
typedef const struct _jc_java_awt_font_GraphicAttribute$vtable	_jc_java_awt_font_GraphicAttribute$vtable;
typedef const struct _jc_java_awt_font_GraphicAttribute$vtype	_jc_java_awt_font_GraphicAttribute$vtype;

// Class fields structure
struct _jc_java_awt_font_GraphicAttribute$fields_struct {
	jint	BOTTOM__5fALIGNMENT;
	jint	CENTER__5fBASELINE;
	jint	HANGING__5fBASELINE;
	jint	ROMAN__5fBASELINE;
	jint	TOP__5fALIGNMENT;
};
extern _jc_java_awt_font_GraphicAttribute$fields_struct _jc_java_awt_font_GraphicAttribute$class_fields;

// Constructors
extern void _jc_java_awt_font_GraphicAttribute$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *, jint);

// Virtual methods
extern void _jc_java_awt_font_GraphicAttribute$method$draw$f3841a017f030b9d(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *, struct _jc_java_awt_Graphics2D$object *, jfloat, jfloat);
extern jfloat _jc_java_awt_font_GraphicAttribute$method$getAdvance$816f64db01e9ba98(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *);
extern jint _jc_java_awt_font_GraphicAttribute$method$getAlignment$e688bf6ab07808bc(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *);
extern jfloat _jc_java_awt_font_GraphicAttribute$method$getAscent$1128a319fbdd8fc1(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *);
extern struct _jc_java_awt_geom_Rectangle2D$object *_jc_java_awt_font_GraphicAttribute$method$getBounds$5108fa3dfa118dd0(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *);
extern jfloat _jc_java_awt_font_GraphicAttribute$method$getDescent$38195f27867c5f73(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *);
extern struct _jc_java_awt_font_GlyphJustificationInfo$object *_jc_java_awt_font_GraphicAttribute$method$getJustificationInfo$6ef1b9622b63b164(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_font_GraphicAttribute$method_info$draw$f3841a017f030b9d;
extern _jc_method _jc_java_awt_font_GraphicAttribute$method_info$getAdvance$816f64db01e9ba98;
extern _jc_method _jc_java_awt_font_GraphicAttribute$method_info$getAlignment$e688bf6ab07808bc;
extern _jc_method _jc_java_awt_font_GraphicAttribute$method_info$getAscent$1128a319fbdd8fc1;
extern _jc_method _jc_java_awt_font_GraphicAttribute$method_info$getBounds$5108fa3dfa118dd0;
extern _jc_method _jc_java_awt_font_GraphicAttribute$method_info$getDescent$38195f27867c5f73;
extern _jc_method _jc_java_awt_font_GraphicAttribute$method_info$getJustificationInfo$6ef1b9622b63b164;

// Virtual methods structure
struct _jc_java_awt_font_GraphicAttribute$vmethods {
	void	(*draw$f3841a017f030b9d)(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *, struct _jc_java_awt_Graphics2D$object *, jfloat, jfloat);
	jfloat	(*getAdvance$816f64db01e9ba98)(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *);
	jint	(*getAlignment$e688bf6ab07808bc)(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *);
	jfloat	(*getAscent$1128a319fbdd8fc1)(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *);
	struct _jc_java_awt_geom_Rectangle2D$object	*(*getBounds$5108fa3dfa118dd0)(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *);
	jfloat	(*getDescent$38195f27867c5f73)(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *);
	struct _jc_java_awt_font_GlyphJustificationInfo$object	*(*getJustificationInfo$6ef1b9622b63b164)(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *);
};

// Vtable
struct _jc_java_awt_font_GraphicAttribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_font_GraphicAttribute$vmethods	java_awt_font_GraphicAttribute;
};

// Vtype
struct _jc_java_awt_font_GraphicAttribute$vtype {
	_jc_type			type;
	_jc_java_awt_font_GraphicAttribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_font_GraphicAttribute$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_font_GraphicAttribute$refs {
    _jc_java_awt_font_GraphicAttribute$sub_refs	java_awt_font_GraphicAttribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_font_GraphicAttribute$sub_nonrefs {
	jint	alignment;
};

// Non-reference instance fields (object)
struct _jc_java_awt_font_GraphicAttribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_font_GraphicAttribute$sub_nonrefs	java_awt_font_GraphicAttribute;
};

// Object instance structure
struct _jc_java_awt_font_GraphicAttribute$object {
	_jc_java_awt_font_GraphicAttribute$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_font_GraphicAttribute$vtype	*vtype;
	_jc_java_awt_font_GraphicAttribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_font_GraphicAttribute$vtype _jc_java_awt_font_GraphicAttribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_font_GraphicAttribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_font_GraphicAttribute$class_object;

#endif	/* _JC_java_awt_font_GraphicAttribute_H_ */

==> jc-1.4.6.tar.gz: java/awt/font/GraphicAttribute.h <==
// public abstract class java.awt.font.GraphicAttribute

// class file dependencies
// @dep_class a87844304b3211dc java_awt_font_GraphicAttribute
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_font_GraphicAttribute_H_
#define _JC_java_awt_font_GraphicAttribute_H_

// Forward structure declarations
struct _jc_java_awt_Graphics2D$object;
struct _jc_java_awt_font_GlyphJustificationInfo$object;
struct _jc_java_awt_geom_Rectangle2D$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_font_GraphicAttribute$sub_refs	_jc_java_awt_font_GraphicAttribute$sub_refs;
typedef struct _jc_java_awt_font_GraphicAttribute$sub_nonrefs	_jc_java_awt_font_GraphicAttribute$sub_nonrefs;
typedef struct _jc_java_awt_font_GraphicAttribute$refs	_jc_java_awt_font_GraphicAttribute$refs;
typedef struct _jc_java_awt_font_GraphicAttribute$nonrefs	_jc_java_awt_font_GraphicAttribute$nonrefs;
typedef struct _jc_java_awt_font_GraphicAttribute$object	_jc_java_awt_font_GraphicAttribute$object;

typedef struct _jc_java_awt_font_GraphicAttribute$fields_struct	_jc_java_awt_font_GraphicAttribute$fields_struct;
typedef const struct _jc_java_awt_font_GraphicAttribute$vmethods	_jc_java_awt_font_GraphicAttribute$vmethods;
typedef const struct _jc_java_awt_font_GraphicAttribute$vtable	_jc_java_awt_font_GraphicAttribute$vtable;
typedef const struct _jc_java_awt_font_GraphicAttribute$vtype	_jc_java_awt_font_GraphicAttribute$vtype;

// Class fields structure
struct _jc_java_awt_font_GraphicAttribute$fields_struct {
	jint	BOTTOM__5fALIGNMENT;
	jint	CENTER__5fBASELINE;
	jint	HANGING__5fBASELINE;
	jint	ROMAN__5fBASELINE;
	jint	TOP__5fALIGNMENT;
};
extern _jc_java_awt_font_GraphicAttribute$fields_struct _jc_java_awt_font_GraphicAttribute$class_fields;

// Constructors
extern void _jc_java_awt_font_GraphicAttribute$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_font_GraphicAttribute$method$draw$f3841a017f030b9d(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *, struct _jc_java_awt_Graphics2D$object *, jfloat, jfloat) _JC_JCNI_ATTR;
extern jfloat _jc_java_awt_font_GraphicAttribute$method$getAdvance$816f64db01e9ba98(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_font_GraphicAttribute$method$getAlignment$e688bf6ab07808bc(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *) _JC_JCNI_ATTR;
extern jfloat _jc_java_awt_font_GraphicAttribute$method$getAscent$1128a319fbdd8fc1(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_geom_Rectangle2D$object *_jc_java_awt_font_GraphicAttribute$method$getBounds$5108fa3dfa118dd0(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *) _JC_JCNI_ATTR;
extern jfloat _jc_java_awt_font_GraphicAttribute$method$getDescent$38195f27867c5f73(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_font_GlyphJustificationInfo$object *_jc_java_awt_font_GraphicAttribute$method$getJustificationInfo$6ef1b9622b63b164(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_font_GraphicAttribute$method_info$draw$f3841a017f030b9d;
extern _jc_method _jc_java_awt_font_GraphicAttribute$method_info$getAdvance$816f64db01e9ba98;
extern _jc_method _jc_java_awt_font_GraphicAttribute$method_info$getAlignment$e688bf6ab07808bc;
extern _jc_method _jc_java_awt_font_GraphicAttribute$method_info$getAscent$1128a319fbdd8fc1;
extern _jc_method _jc_java_awt_font_GraphicAttribute$method_info$getBounds$5108fa3dfa118dd0;
extern _jc_method _jc_java_awt_font_GraphicAttribute$method_info$getDescent$38195f27867c5f73;
extern _jc_method _jc_java_awt_font_GraphicAttribute$method_info$getJustificationInfo$6ef1b9622b63b164;

// Virtual methods structure
struct _jc_java_awt_font_GraphicAttribute$vmethods {
	void	(*draw$f3841a017f030b9d)(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *, struct _jc_java_awt_Graphics2D$object *, jfloat, jfloat) _JC_JCNI_ATTR;
	jfloat	(*getAdvance$816f64db01e9ba98)(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *) _JC_JCNI_ATTR;
	jint	(*getAlignment$e688bf6ab07808bc)(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *) _JC_JCNI_ATTR;
	jfloat	(*getAscent$1128a319fbdd8fc1)(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_geom_Rectangle2D$object	*(*getBounds$5108fa3dfa118dd0)(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *) _JC_JCNI_ATTR;
	jfloat	(*getDescent$38195f27867c5f73)(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_font_GlyphJustificationInfo$object	*(*getJustificationInfo$6ef1b9622b63b164)(_jc_env *, struct _jc_java_awt_font_GraphicAttribute$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_font_GraphicAttribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_font_GraphicAttribute$vmethods	java_awt_font_GraphicAttribute;
};

// Vtype
struct _jc_java_awt_font_GraphicAttribute$vtype {
	_jc_type			type;
	_jc_java_awt_font_GraphicAttribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_font_GraphicAttribute$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_font_GraphicAttribute$refs {
    _jc_java_awt_font_GraphicAttribute$sub_refs	java_awt_font_GraphicAttribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_font_GraphicAttribute$sub_nonrefs {
	jint	alignment;
};

// Non-reference instance fields (object)
struct _jc_java_awt_font_GraphicAttribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_font_GraphicAttribute$sub_nonrefs	java_awt_font_GraphicAttribute;
};

// Object instance structure
struct _jc_java_awt_font_GraphicAttribute$object {
	_jc_java_awt_font_GraphicAttribute$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_font_GraphicAttribute$vtype	*vtype;
	_jc_java_awt_font_GraphicAttribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_font_GraphicAttribute$vtype _jc_java_awt_font_GraphicAttribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_font_GraphicAttribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_font_GraphicAttribute$class_object;

#endif	/* _JC_java_awt_font_GraphicAttribute_H_ */
